pub struct Snapshot { /* private fields */ }Expand description
A consistent view of the database at a point in time
Implementations
Sourceimpl Snapshot
impl Snapshot
Sourcepub fn new(
txn_id: TransactionId,
high_water_mark: TransactionId,
in_progress: HashSet<TransactionId>,
) -> Snapshot
pub fn new( txn_id: TransactionId, high_water_mark: TransactionId, in_progress: HashSet<TransactionId>, ) -> Snapshot
Create a new snapshot
Sourcepub fn with_ancestors(
txn_id: TransactionId,
high_water_mark: TransactionId,
in_progress: HashSet<TransactionId>,
ancestors: HashSet<TransactionId>,
) -> Snapshot
pub fn with_ancestors( txn_id: TransactionId, high_water_mark: TransactionId, in_progress: HashSet<TransactionId>, ancestors: HashSet<TransactionId>, ) -> Snapshot
Create a snapshot with visible ancestor transactions
This is used for sub-transactions (savepoints) that need to see their parent transaction’s uncommitted changes.
Sourcepub fn add_ancestor(&mut self, ancestor: TransactionId)
pub fn add_ancestor(&mut self, ancestor: TransactionId)
Add an ancestor transaction whose changes should be visible
Sourcepub fn is_ancestor(&self, txn_id: TransactionId) -> bool
pub fn is_ancestor(&self, txn_id: TransactionId) -> bool
Check if a transaction is an ancestor (part of the same logical transaction)
Sourcepub fn txn_id(&self) -> TransactionId
pub fn txn_id(&self) -> TransactionId
Get the transaction ID of this snapshot
Sourcepub fn sees_all_committed(&self) -> bool
pub fn sees_all_committed(&self) -> bool
Returns true when all committed transactions are visible. This enables the ultra-fast scan path that skips per-row MVCC checks.
Sourcepub fn high_water_mark(&self) -> TransactionId
pub fn high_water_mark(&self) -> TransactionId
Get the high-water mark
Sourcepub fn can_see(&self, created_by: TransactionId) -> bool
pub fn can_see(&self, created_by: TransactionId) -> bool
Check if a transaction’s changes are visible to this snapshot
Sourcepub fn is_visible(
&self,
created_by: TransactionId,
deleted_by: Option<TransactionId>,
) -> bool
pub fn is_visible( &self, created_by: TransactionId, deleted_by: Option<TransactionId>, ) -> bool
Check if a version is visible based on creation and deletion timestamps